-------------
DFTB+ Recipes
-------------

This section mirrors the DFTB+
`recipes <https://dftbplus-recipes.readthedocs.io/en/latest/index.html>`_ on the DFTB+
website, showing them in SEAMM rather than using an editor and the command-line. Some of
the recipes will be extended to make more general recipes.

.. toctree::
   :glob:
   :maxdepth: 0
   :titlesonly:

   *
